@@ -46,7 +46,7 @@ typedef enum
  */
 struct _GstGLQuery
 {
-  /* <private> */
+  /*< private >*/
   GstGLContext *    context;
   guint             query_type;
   guint             query_id;
@@ -55,7 +55,6 @@ struct _GstGLQuery
   gboolean          start_called;
   GstGLAsyncDebug   debug;
 
-  /* <private> */
   gpointer          _padding[GST_PADDING];
 };
 
@@ -96,8 +95,6 @@ guint64             gst_gl_query_result             (GstGLQuery * query);
     gst_gl_async_debug_thaw (&(query)->debug); \
   } G_STMT_END
 
-#if G_HAVE_ISO_VARARGS
-
 #define gst_gl_query_start_log(query,cat,level,object,format,...) \
   G_STMT_START {    \
     GST_GL_ASYNC_CAT_LEVEL_LOG (&(query)->debug, cat, level, object, format, __VA_ARGS__); \
@@ -113,51 +110,6 @@ guint64             gst_gl_query_result             (GstGLQuery * query);
     gst_gl_async_debug_thaw (&(query)->debug); \
   } G_STMT_END
 
-#else /* G_HAVE_ISO_VARARGS */
-#if G_HAVE_GNUC_VARARGS
-
-#define gst_gl_query_start_log(query,cat,level,object,format,args...) \
-  G_STMT_START {    \
-    GST_GL_ASYNC_CAT_LEVEL_LOG (&(query)->debug, cat, level, object, format, ##args); \
-    gst_gl_async_debug_freeze (&(query)->debug); \
-    gst_gl_query_start (query); \
-    gst_gl_async_debug_thaw (&(query)->debug); \
-  } G_STMT_END
-#define gst_gl_query_counter_log(query,cat,level,object,format,args...) \
-  G_STMT_START {    \
-    GST_GL_ASYNC_CAT_LEVEL_LOG (&(query)->debug, cat, level, object, format, ##args); \
-    gst_gl_async_debug_freeze (&(query)->debug); \
-    gst_gl_query_counter (query); \
-    gst_gl_async_debug_thaw (&(query)->debug); \
-  } G_STMT_END
-
-#else /* G_HAVE_GNUC_VARARGS */
-
-static inline void
-gst_gl_query_start_log(GstGLQuery * query, GstDebugCategory * cat,
-    GstDebugLevel level, GObject * object, const gchar * format, ...)
-{
-  va_list varargs;
-
-  va_start (varargs, format);
-  gst_gl_query_start_log_valist (query, cat, level, object, format, varargs);
-  va_end (varargs);
-}
-
-static inline void
-gst_gl_query_counter_log(GstGLQuery * query, GstDebugCategory * cat,
-    GstDebugLevel level, GObject * object, const gchar * format, ...)
-{
-  va_list varargs;
-
-  va_start (varargs, format);
-  gst_gl_query_counter_log_valist (query, cat, level, object, format, varargs);
-  va_end (varargs);
-}
-
-#endif /* G_HAVE_GNUC_VARARGS */
-#endif /* G_HAVE_ISO_VARARGS */
-
 G_END_DECLS
 
 #endif /* __GST_GL_QUERY_H__ */
